Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3994)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/ntp/cards/AllDismissedItem.java

Issue 2396523002: Unify NewTabPageItem and ItemGroup into a single tree-structured interface. (Closed)
Patch Set: oo Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/ntp/cards/AllDismissedItem.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/ntp/cards/AllDismissedItem.java b/chrome/android/java/src/org/chromium/chrome/browser/ntp/cards/AllDismissedItem.java
index 040a14cf651b8d1e3e1f265394abd6a4d6a6bac8..7d3991276a6e20f2f02043ac1e3c0e3d1eec7f02 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/ntp/cards/AllDismissedItem.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/ntp/cards/AllDismissedItem.java
@@ -22,10 +22,11 @@ import java.util.Calendar;
* Displayed when all suggested content and their sections have been dismissed. Provides a button
* to restore the dismissed sections and load new suggestions from the server.
*/
-public class AllDismissedItem extends SingleItemGroup {
+public class AllDismissedItem extends Leaf {
@Override
- public int getType() {
- return NewTabPageItem.VIEW_TYPE_ALL_DISMISSED;
+ @ItemViewType
+ public int getItemViewType() {
+ return ItemViewType.VIEW_TYPE_ALL_DISMISSED;
}
@Override
@@ -35,7 +36,7 @@ public class AllDismissedItem extends SingleItemGroup {
}
/**
* ViewHolder for an item of type {@link #VIEW_TYPE_ALL_DISMISSED}.
*/
public static class ViewHolder extends NewTabPageViewHolder {
private final TextView mBodyTextView;
@@ -35,7 +36,7 @@ public class AllDismissedItem extends SingleItemGroup {
}
/**
- * ViewHolder for an item of type {@link #VIEW_TYPE_ALL_DISMISSED}.
+ * ViewHolder for an item of type {@link ItemViewType#VIEW_TYPE_ALL_DISMISSED}.
*/
public static class ViewHolder extends NewTabPageViewHolder {

Powered by Google App Engine
This is Rietveld 408576698